@@ -24,7 +24,7 @@ class _Parameter():
 
     @value.setter
     def value(self, value):
-        if not isinstance(value, float) or not isinstance(value, int):
+        if not (isinstance(value, float) or isinstance(value, int)):
             raise RuntimeError('value must be float or int type')
         #end if        
         if self._document_type == 'System':
@@ -129,9 +129,6 @@ class _Elements():
         return elements_list
 
     def add_element(self, element_name, x_pos: float, y_pos: float, rotation: float=0, flipped: bool=False):
-
-        #TODO!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-        #
         '''
         Add an element to the document
         
@@ -151,12 +148,25 @@ class _Elements():
         none
                     
         '''          
-        pass
+        if not isinstance(element_name, str):
+            raise TypeError('element_name must be string type')
+        if not (isinstance(x_pos, float) or isinstance(x_pos, int)):
+            raise TypeError('x_pos must be float or int type')
+        if not (isinstance(y_pos, float) or isinstance(y_pos, int)):
+            raise TypeError('y_pos must be float or int type')
+        if not (isinstance(rotation, float) or isinstance(rotation, int)):
+            raise TypeError('rotation must be float or int type') 
+        if not isinstance(flipped, bool):
+            raise TypeError('flipped must be bool type')
+        #end if
+        #
+        try:
+            self._document.Elements.Add(element_name, x_pos, y_pos, rotation, flipped)
+        except:
+            raise RuntimeError('Error when adding element: '+element_name)
+        #end try
         #
     def remove_element(self, element_name_n_id: str) -> bool:#-----------------------------------------
-        #
-        #TODO!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-        #
         '''
         Delete an element from the document
         
@@ -173,7 +183,22 @@ class _Elements():
                     False if element could not be deleted
                     
         '''          
-        pass
+        if not isinstance(element_name_n_id, str):
+            raise TypeError('element_name_n_id must be a string')
+        #end if
+        element_removed = False
+        try:
+            for ele_idx in range(self._document.Elements.Count):
+                if self._document.Elements[ele_idx].Name == element_name_n_id:
+                    self._document.Elements.Remove(ele_idx+1)
+                    element_removed = True
+                    break
+                #end if
+            #end for
+        except:
+            warnings.warn('remove_element: Element ' + element_name_n_id + ' did not get removed')
+        #end try
+        return element_removed
         #
 #
 #**********************************************************************************************
@@ -186,6 +211,24 @@ class _Element(_Parameters):
         #
     def set_optimization(self, optimization_bounds: np.ndarray ) -> bool:
         pass
+        #
+    @property
+    def element_name(self) -> str: #------------------------------------------
+        '''returns element name'''
+        return self._element.Name
+        #    
+    @property
+    def xy_position(self) -> tuple:#-------------------------------------------------
+        x_position = self._element.x
+        y_position = self._element.y
+        xy_position_tuple = (x_position, y_position)
+        return xy_position_tuple
+        #    
+    def set_xy_position(self, xy_position_tuple: tuple):#------------------------------
+        '''set xy position'''
+        self._element.x = xy_position_tuple[0]
+        self._element.y = xy_position_tuple[1]
+        #    
 #
 #**********************************************************************************************
 #
